# ErrorMessage

Object describing error codes for the agilicus APIs
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**error_code** | **str** | A shortform error code for identifying the error. See error_message for details | [optional] 
**error_message** | **str** | A longform description detailing how the user can resolve the error | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


